kill

Function kill 

pub fn kill(vid: &VmId) -> Result<(), Error>
Terminate a virtual machine by UUID or name.

Killing a virtual machine is normally not a good idea, but it can be useful if the virtual machine is anyway going to be reinstalled or restored to a snapshot.